SystemOrganization addCategory: #'AmbientTalkST-Benchmarks'!

BenchmarkGameSuite subclass: #ATBenchmarkGameSuite
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATBenchmarkGameSuite methodsFor: 'benchmarking' stamp: 'StefanMarr 1/3/2012 20:04'!
benchATBinaryTrees
	| bench problemSize treeActor benchActor treeFactory result |
	problemSize := self problemSize
			ifNotNil: [ self problemSize ]
			ifNil:    [ BGBinaryTrees defaultProblemSize ].
	
	treeActor := self createActor.
	benchActor := self createActor.
	
	treeFactory := treeActor adoptObject: BGTreeNode.
	
	bench := BGBinaryTrees new.
	bench binaryTreeFactory: treeFactory.
	
	result := benchActor evaluateAsync: [
		bench binarytrees: problemSize to: (TextStream with: String new).
	].
	
	^ result read.! !

!ATBenchmarkGameSuite methodsFor: 'benchmarking' stamp: 'StefanMarr 1/3/2012 20:04'!
benchATFasta
	| randomnessActor bodies out bench |
	bench := BGFasta new.
	bench n: (self problemSize
						ifNotNil: [ self problemSize ]
						ifNil:    [ BGFasta defaultProblemSize ]).
	out := TextStream with: String new.
	bench out: out.
	
	randomnessActor := self createActor.
	
	bench repeatStreamFact: (randomnessActor adoptObject: BGRepeatStream).
	bench oneHomoSapiensAlu.
	
	bench r: (randomnessActor adoptObject: (BGRandomNumber to: 1)).
	bench randomStreamFact: (randomnessActor adoptObject: BGRandomStream).
	
	bench twoIUBAmbiguityCodes.
	bench threeHomoSapiensFrequency.
	
	out flush.
	
	^ out contents.! !

!ATBenchmarkGameSuite methodsFor: 'benchmarking' stamp: 'StefanMarr 1/3/2012 20:04'!
benchATNBody
	| problemSize bodiesActor bodies |
	problemSize := self problemSize
			ifNotNil: [ self problemSize ]
			ifNil:    [ BGNBody defaultProblemSize ].

	bodiesActor := self createActor.
	
	bodies := bodiesActor adoptObject: BGNBodySystem new. 
	
	^ BGNBody nbody: problemSize with: bodies.
! !

!ATBenchmarkGameSuite methodsFor: 'tracing' stamp: 'StefanMarr 1/3/2012 20:04'!
createActor
	^ ATActor new! !

ATBenchmarkGameSuite subclass: #ATBenchmarkGameSuiteTraced
	instanceVariableNames: 'actors'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATBenchmarkGameSuiteTraced methodsFor: 'accessing' stamp: 'StefanMarr 1/3/2012 22:08'!
actors
	^ actors! !

!ATBenchmarkGameSuiteTraced methodsFor: 'tracing' stamp: 'StefanMarr 1/3/2012 22:08'!
createActor
	| actor |
	actor := ATTracingActor new.
	actors add: actor.
	^ actor! !

!ATBenchmarkGameSuiteTraced methodsFor: 'initialization' stamp: 'StefanMarr 1/3/2012 22:08'!
initialize
	super initialize.
	actors := OrderedCollection new.! !

TestCase subclass: #ATBenchmarkTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 1/3/2012 22:48'!
testATBinaryTrees
	| bench actors |
	bench := ATBenchmarkGameSuiteTraced new.
	self assert: -1 equals: bench benchATBinaryTrees.
	
	actors := bench actors.
	
	self assert: 2 equals: actors size.
	
	self assert: 2692 equals: (actors at: 1) numberOfProcessedMessages. "Tree actor"
	self assert: 1    equals: (actors at: 2) numberOfProcessedMessages. "Bench actor"
	! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 1/3/2012 22:12'!
testATFasta
	| atBench result actors |
	atBench := ATBenchmarkGameSuiteTraced new.
	result := atBench benchATFasta.
	
	self assert: result equals: BGFasta fasta.
	
	actors := atBench actors.
	
	self assert: 1 equals: actors size.
	
	self assert: 20010 equals: (actors at: 1) numberOfProcessedMessages. "randomness actor"! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 1/3/2012 21:18'!
testATFloatLoop
	| bench actors |
	bench := ATBenchLoopsTraced new.
	self assert: #done equals: bench benchATFloatLoop.
	
	actors := bench actors.
	
	self assert: 1 equals: actors size.
	self assert: 1 equals: (actors at: 1) numberOfProcessedMessages.! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 1/3/2012 20:49'!
testATIntLoop
	| bench actors |
	bench := ATBenchLoopsTraced new.
	self assert: #done equals: bench benchATIntLoop.
	actors := bench actors.
	
	self assert: 1 equals: actors size.
	self assert: 1 equals: (actors at: 1) numberOfProcessedMessages.! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 1/3/2012 22:14'!
testATNBody
	| bench result actors |
	bench := ATBenchmarkGameSuiteTraced new.
	result := bench benchATNBody.
	
	self assert: (((result at: 2) asString) beginsWith: '-0.169087605').
	
	actors := bench actors.
	
	self assert: 1 equals: actors size.
	
	self assert: (BGNBody defaultProblemSize + 3) equals: (actors at: 1) numberOfProcessedMessages. "bodies actor"	! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 1/3/2012 22:26'!
testLocalSend
	| bench actors result |
	bench := ATMicroBenchmarksTraced new.
	result := bench benchLocalSend.
	
	self assert: ATMicroBenchmarks defaultProblemSize
	     equals: result.
	
	actors := bench actors.
	
	self assert: 1 equals: actors size.
	
	self assert: 1 equals: (actors at: 1) numberOfProcessedMessages.! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 1/3/2012 22:48'!
testRemoteSend
	| bench actors result |
	bench := ATMicroBenchmarksTraced new.
	result:= bench benchRemoteSend.
	
	self assert: ATMicroBenchmarks defaultProblemSize
	     equals: result.
	
	actors := bench actors.
	
	self assert: 2 equals: actors size.
	
	self assert: 1          equals: (actors at: 1) numberOfProcessedMessages. "counting actor"
	self assert: result + 1 equals: (actors at: 2) numberOfProcessedMessages. "counter actor"
	! !

!ATBenchmarkTests methodsFor: 'tests' stamp: 'StefanMarr 1/3/2012 22:48'!
testRemoteSendWithManyArguments
	| bench result actors |
	bench := ATMicroBenchmarksTraced new.
	result:= bench benchRemoteSendWithManyArguments.
	
	self assert: ATMicroBenchmarks defaultProblemSize
	     equals: result.
	
	
	actors := bench actors.
	
	self assert: 2 equals: actors size.
	
	self assert: 1          equals: (actors at: 1) numberOfProcessedMessages. "counting actor"
	self assert: result + 1 equals: (actors at: 2) numberOfProcessedMessages. "counter actor"
	! !

SMarkSuite subclass: #ATBenchmarks
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATBenchmarks methodsFor: 'tracing' stamp: 'StefanMarr 1/3/2012 20:01'!
createActor
	^ ATActor new! !

ATBenchmarks subclass: #ATMicroBenchmarks
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATMicroBenchmarks class methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/2/2012 17:52'!
defaultProblemSize
	^ 10000! !

!ATMicroBenchmarks methodsFor: 'benchmarking' stamp: 'StefanMarr 1/3/2012 20:02'!
benchLocalSend
	"In the omni version this one should be sensitive to field updates which will probably be measurable"
	| actor result |
	actor := self createActor.
	
	result := actor evaluateAsync: [
		| o |
		o := ATMicroSubject new.
		1 to: self problemSize do: [:i|
			o incCounter.
		].
		o counter
	].

	^ result read! !

!ATMicroBenchmarks methodsFor: 'benchmarking' stamp: 'StefanMarr 1/3/2012 20:03'!
benchRemoteSend
	| actor cntActor cnt result |
	actor := self createActor.
	cntActor := self createActor.
	
	cnt := cntActor adoptObject: ATMicroSubject new.
	
	result := actor evaluateAsync: [
		1 to: self problemSize do: [:i|
			cnt incCounter.
		].
		cnt counter
	].

	^ result read! !

!ATMicroBenchmarks methodsFor: 'benchmarking' stamp: 'StefanMarr 1/3/2012 22:35'!
benchRemoteSendWithManyArguments
	| actor cntActor cnt result |
	actor := self createActor.
	cntActor := self createActor.
	
	cnt := cntActor adoptObject: ATMicroSubject new.
	
	[ cnt class == ATFarReference ] assert.
	
	result := actor evaluateAsync: [
		1 to: self problemSize do: [:i|
			cnt process: i a: i b: i c: i d: i e: i f: i g: i h: i i: i.
		].
		cnt counter
	].

	^ result read! !

ATMicroBenchmarks subclass: #ATMicroBenchmarksTraced
	instanceVariableNames: 'actors'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATMicroBenchmarksTraced methodsFor: 'accessing' stamp: 'StefanMarr 1/3/2012 22:23'!
actors
	^ actors! !

!ATMicroBenchmarksTraced methodsFor: 'tracing' stamp: 'StefanMarr 1/3/2012 22:23'!
createActor
	| actor |
	actor := ATTracingActor new.
	actors add: actor.
	^ actor! !

!ATMicroBenchmarksTraced methodsFor: 'initialization' stamp: 'StefanMarr 1/3/2012 22:23'!
initialize
	super initialize.
	actors := OrderedCollection new.! !

SMarkLoops subclass: #ATBenchLoops
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATBenchLoops methodsFor: 'benchmarking' stamp: 'StefanMarr 1/3/2012 20:03'!
benchATFloatLoop
	| promise actor |
	
	actor := self createActor.
	promise := actor evaluateAsync: [
		self benchFloatLoop.
		#done
	].

	^ promise read! !

!ATBenchLoops methodsFor: 'benchmarking' stamp: 'StefanMarr 1/3/2012 20:03'!
benchATIntLoop
	| promise actor |
	
	actor := self createActor.
	promise := actor evaluateAsync: [
		self benchIntLoop.
		#done
	].

	^ promise read! !

!ATBenchLoops methodsFor: 'tracing' stamp: 'StefanMarr 1/3/2012 20:03'!
createActor
	^ ATActor new! !

ATBenchLoops subclass: #ATBenchLoopsTraced
	instanceVariableNames: 'actors'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATBenchLoopsTraced methodsFor: 'accessing' stamp: 'StefanMarr 1/3/2012 20:36'!
actors
	^ actors! !

!ATBenchLoopsTraced methodsFor: 'tracing' stamp: 'StefanMarr 1/3/2012 20:36'!
createActor
	| actor |
	actor := ATTracingActor new.
	actors add: actor.
	^ actor! !

!ATBenchLoopsTraced methodsFor: 'initialization' stamp: 'StefanMarr 1/3/2012 20:36'!
initialize
	super initialize.
	actors := OrderedCollection new.! !

Object subclass: #ATMicroSubject
	instanceVariableNames: 'cnt'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Benchmarks'!

!ATMicroSubject methodsFor: 'accessing' stamp: 'StefanMarr 1/2/2012 14:32'!
counter
	^ cnt! !

!ATMicroSubject methodsFor: 'testing helpers' stamp: 'StefanMarr 1/2/2012 14:31'!
incCounter
	cnt := cnt + 1.! !

!ATMicroSubject methodsFor: 'initialization' stamp: 'StefanMarr 1/2/2012 14:31'!
initialize
	super initialize.
	cnt := 0.! !

!ATMicroSubject methodsFor: 'testing helpers' stamp: 'StefanMarr 1/2/2012 14:41'!
process: z a: a b: b c: c d: d e: e f: f g: g h: h i: i
	cnt := cnt + 1.! !
